import { gql } from '@apollo/client/core'

import { UserAvatarFragment } from '@holi/core/domain/shared/queries'
import { User } from '@holi/core/domain/shared/types'
import { Task } from '@holi/core/screens/spaces/types'
import { Paged } from '@holi/core/types'

export type NumberOfItems = {
  numberOfItems: number
}

export const userSuggestionsQuery = gql`
  ${UserAvatarFragment}

  query UserSuggestions($limit: Int! = 10) {
    userSuggestions(limit: $limit) {
      data {
        ...UserAvatar
        aboutMe
      }
    }
  }
`

export type UserSuggestionsResponse = {
  userSuggestions: Paged<User>
}

export enum NeedUpdateType {
  NO = 'NO',
  RECOMMENDED = 'RECOMMENDED',
  MANDATORY = 'MANDATORY',
}

export type NeedUpdate = {
  needUpdate: NeedUpdateType
  appStoreUrl: string
  playStoreUrl: string
}

export const checkAppVersionQuery = gql`
  query CheckAppVersion($version: String!, $buildNumber: String!) {
    checkAppVersion(version: $version, buildNumber: $buildNumber) {
      needUpdate
      appStoreUrl
      playStoreUrl
    }
  }
`

export type CheckAppVersionResponse = {
  checkAppVersion: NeedUpdate
}

const taskFragment = gql`
  fragment TaskFragment on Task {
    id
    name
    description
    space {
      id
      title
      name
      avatar
      avatarBlurhash
      avatarDefaultColor
    }
    thumbnail
    thumbnailBlurhash
    location
    locationType
    regularity
    skills {
      id
      title
      slug
    }
  }
`

export const recommendedTasksQuery = gql`
  ${taskFragment}
  query RecommendedTasks($limit: Int) {
    recommendedTasks(limit: $limit) {
      data {
        ...TaskFragment
      }
      totalResults
    }
  }
`

export type RecommendedTasksQueryResponse = {
  recommendedTasks: Paged<Task>
}
